(function ($) {

  $(document).ready(function() {
    if (Drupal.settings.services_sso_client.auto_login_via_js) {
      $.ajax({
        url: Drupal.settings.services_sso_client.base_url + '/sso/init.json',
        success: function(data) {
          if (data.redirect && Drupal.settings.services_sso_client.auto_login_via_js_redirect) {
            $('<div/>', {id: 'redirect-overlay'}).css({
              'position': 'absolute',
              'top': 0,
              'bottom': 0,
              'left': 0,
              'right': 0,
              'background': '#000',
              'height': $('body').height(),
              'filter': 'alpha(opacity=70)',
              'opacity': '0.7',
              'z-index': '9999'
            }).appendTo('body');

            switch (data.redirect_path) {
              case '<current>':
              case '':
                document.location.reload(true);
                break;
              case '<front>':
                window.location.href = '/';
                break;
              default:
                window.location.href = data.redirect_path;
                break;
            }
          }
        }
      });
    }
  });

  Drupal.behaviors.services_sso_client = {
    attach: function(context, settings) {
      // Attach colorbox to edit links. This falls back gracefully without JS.
      jQuery('a.load-modal', context).each(function(i) {
        jQuery(this).colorbox({
          speed: 500,
          iframe: true,
          width: 1000,
          height: '80%',

          onClosed: function() {
            // Force a page refresh after colorbox has been closed.
            window.location.reload(false);
          }
        });
      });

      // Reproduce the password repeating function on the user registration form for emails as well.
      // Trying to follow user.js style in the core user module.
      $('.confirm-email-wrapper .form-item-mail input', context).once('email', function () {
        var translate = settings.services_sso_client.email_translate;

        var emailInput = $(this);
        var innerWrapper = $(this).parent();
        var outerWrapper = $(this).parent().parent();

        innerWrapper.addClass('email-parent');

        var confirmInput = $('.form-item-mail-confirm input', outerWrapper);
        confirmInput.parent().prepend('<div class="email-confirm">' + translate['confirmTitle'] + '<span></span></div>').addClass('confirm-parent');
        var confirmResult = $('div.email-confirm', outerWrapper);
        var confirmChild = $('span', confirmResult);

        // Check that email and confirmation inputs match.
        var emailCheckMatch = function () {

          if (confirmInput.val()) {
            var success = emailInput.val() === confirmInput.val();

            // Show the confirm result.
            confirmResult.css({ visibility: 'visible' });

            // Remove the previous styling if any exists.
            if (this.confirmClass) {
              confirmChild.removeClass(this.confirmClass);
            }

            // Fill in the success message and set the class accordingly.
            var confirmClass = success ? 'ok' : 'error';
            confirmChild.html(translate['confirm' + (success ? 'Success' : 'Failure')]).addClass(confirmClass);
            this.confirmClass = confirmClass;
          }
          else {
            confirmResult.css({ visibility: 'hidden' });
          }


        };

        confirmInput.keyup(emailCheckMatch).blur(emailCheckMatch);
        emailInput.keyup(emailCheckMatch).blur(emailCheckMatch);
      });
    }
  };
})(jQuery);
